## dasf-messaging-python

Python module wrapper for the data analytics software framework DASF.
Developed and tested with Python 3.8

### Scope

This library is part of the Data Analytics Software Framework DASF (https://git.geomar.de/digital-earth/dasf), 
which was developed by the GFZ Potsdam (https://www.gfz-potsdam.de) 
in the Digital Earth project (https://www.digitalearth-hgf.de/).

---

### Howto use it

see: https://git.geomar.de/digital-earth/dasf/dasf-messaging-python/-/blob/master/ExampleMessageConsumer.py

- generate the counterpart via `python ExampleMessageConsumer.py generate > ExampleMessageProducerGen.py`
- call the consumer module via the generated producer,
see https://git.geomar.de/digital-earth/dasf/dasf-messaging-python/-/blob/master/ExampleMessageProducer.py

